@@ -64,7 +64,7 @@ class AuthorisationService(object):
             for auth in response.json()['resources']:
                 auths.append(Authorisation(auth))
             page = Page(response.json(), auths)
-            logging.info('Found {} authorisations'.format(
+            logging.debug('Found {} authorisations'.format(
                                             len(page.resources)))
             return page
         else:
@@ -92,7 +92,7 @@ class AuthorisationService(object):
 
         if response.status_code == 201:
             auth = Authorisation(response.json())
-            logging.info('Successfully created authorisation with id {}'.format(
+            logging.debug('Successfully created authorisation with id {}'.format(
                                 auth.id))
             return auth
         else:
@@ -114,7 +114,7 @@ class AuthorisationService(object):
                             auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found authorisation with id {}'.format(authId))
+            logging.debug('Found authorisation with id {}'.format(authId))
             return Authorisation(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -147,7 +147,7 @@ class AuthorisationService(object):
 
         if response.status_code is 200:
             auth = Authorisation(response.json())
-            logging.info('Successfully modified authorisation with the id {}'
+            logging.debug('Successfully modified authorisation with the id {}'
                         .format(auth.id))
             return auth
         else:
@@ -167,7 +167,7 @@ class AuthorisationService(object):
                     auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully deleted authorisation with id {}'.format(authId))
+            logging.debug('Successfully deleted authorisation with id {}'.format(authId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
                                      response.status_code)
@@ -185,7 +185,7 @@ class AuthorisationService(object):
                     auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully revoked authorisation with id {}'.format(authId))
+            logging.debug('Successfully revoked authorisation with id {}'.format(authId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
                                      response.status_code)
@@ -216,7 +216,7 @@ class AuthorisationService(object):
             for type in response.json()['resources']:
                 types.append(AuthorisationType(type))
             page = Page(response.json(), types)
-            logging.info('Found {} authorisation types'.format(
+            logging.debug('Found {} authorisation types'.format(
                                             len(page.resources)))
             return page
         else:
@@ -244,7 +244,7 @@ class AuthorisationService(object):
 
         if response.status_code == 201:
             auth_type = AuthorisationType(response.json())
-            logging.info('Successfully created authorisation type with id {}'.format(
+            logging.debug('Successfully created authorisation type with id {}'.format(
                                 auth_type.id))
             return auth_type
         else:
@@ -266,7 +266,7 @@ class AuthorisationService(object):
                         auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found authorisation type with id {}'.format(typeId))
+            logging.debug('Found authorisation type with id {}'.format(typeId))
             return AuthorisationType(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -298,7 +298,7 @@ class AuthorisationService(object):
 
         if response.status_code is 200:
             auth_type = AuthorisationType(response.json())
-            logging.info('Successfully modified authorisation type with the id {}'
+            logging.debug('Successfully modified authorisation type with the id {}'
                         .format(auth_type.id))
             return auth_type
         else:
@@ -318,7 +318,7 @@ class AuthorisationService(object):
                         auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully deleted authorisation type with id {}'.format(typeId))
+            logging.debug('Successfully deleted authorisation type with id {}'.format(typeId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
                                      response.status_code)
@@ -349,7 +349,7 @@ class AuthorisationService(object):
             for source in response.json()['resources']:
                 sources.append(AuthorisationType(source))
             page = Page(response.json(), sources)
-            logging.info('Found {} authorisation sources'.format(
+            logging.debug('Found {} authorisation sources'.format(
                                             len(page.resources)))
             return page
         else:
@@ -377,7 +377,7 @@ class AuthorisationService(object):
 
         if response.status_code == 201:
             auth_source = AuthorisationType(response.json())
-            logging.info('Successfully created authorisation type with id {}'.format(
+            logging.debug('Successfully created authorisation type with id {}'.format(
                                 auth_source.id))
             return auth_source
         else:
@@ -399,7 +399,7 @@ class AuthorisationService(object):
                       auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found authorisation source with id {}'.format(sourceId))
+            logging.debug('Found authorisation source with id {}'.format(sourceId))
             return AuthorisationType(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -431,7 +431,7 @@ class AuthorisationService(object):
 
         if response.status_code is 200:
             auth_source = AuthorisationType(response.json())
-            logging.info('Successfully modified authorisation type with the id {}'
+            logging.debug('Successfully modified authorisation type with the id {}'
                         .format(auth_source.id))
             return auth_source
         else:
@@ -451,7 +451,7 @@ class AuthorisationService(object):
                         auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully deleted authorisation source with id {}'.format(sourceId))
+            logging.debug('Successfully deleted authorisation source with id {}'.format(sourceId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
                                      response.status_code)
@@ -483,7 +483,7 @@ class AuthorisationService(object):
             for right in response.json()['resources']:
                 rights.append(AuthorisationGrantRight(right))
             page = Page(response.json(), rights)
-            logging.info('Found {} authorisation grant rights'.format(
+            logging.debug('Found {} authorisation grant rights'.format(
                                             len(page.resources)))
             return page
         else:
@@ -511,7 +511,7 @@ class AuthorisationService(object):
 
         if response.status_code == 201:
             grant_right = AuthorisationGrantRight(response.json())
-            logging.info('Successfully created authorisation grant right with id {}'.format(
+            logging.debug('Successfully created authorisation grant right with id {}'.format(
                                 grant_right.id))
             return grant_right
         else:
@@ -533,7 +533,7 @@ class AuthorisationService(object):
                     auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found authorisation type with id {}'.format(grantId))
+            logging.debug('Found authorisation type with id {}'.format(grantId))
             return AuthorisationGrantRight(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -552,7 +552,7 @@ class AuthorisationService(object):
                 auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully revoked authorisation grant right with id {}'.format(grantId))
+            logging.debug('Successfully revoked authorisation grant right with id {}'.format(grantId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
                                      response.status_code)
