@@ -74,7 +74,7 @@ class ProductService(object):
                         auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found {} catalogs'.format(len(response.json()['resources'])))
+            logging.debug('Found {} catalogs'.format(len(response.json()['resources'])))
             catalogs = []
             for catalog in response.json()['resources']:
                 catalogs.append(Catalog(catalog))
@@ -104,7 +104,7 @@ class ProductService(object):
 
         if response.status_code == 201:
             catalog = Catalog(response.json())
-            logging.info('Successfully created catalog with id {}'.format(
+            logging.debug('Successfully created catalog with id {}'.format(
                                 catalog.id))
             return catalog
         else:
@@ -137,7 +137,7 @@ class ProductService(object):
 
         if response.status_code is 200:
             crd = Catalog(response.json())
-            logging.info('Successfully modified catalog with the id {}'
+            logging.debug('Successfully modified catalog with the id {}'
                                                     .format(crd.id))
             return crd
         else:
@@ -159,7 +159,7 @@ class ProductService(object):
                 auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found catalog with id {}'.format(catalogId))
+            logging.debug('Found catalog with id {}'.format(catalogId))
             return Catalog(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -178,7 +178,7 @@ class ProductService(object):
                 auth=self._auth)
 
         if response.status_code is 204:
-            logging.info(
+            logging.debug(
                     'Successfully deleted catalog with id {}'.format(catalogId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -221,7 +221,7 @@ class ProductService(object):
                                 auth=self._auth)
 
         if response.status_code == 200:
-            logging.info('Found {} pricing plan objects'.format(
+            logging.debug('Found {} pricing plan objects'.format(
                         len(response.json()['resources'])))
 
             ls = []
@@ -254,7 +254,7 @@ class ProductService(object):
 
         if response.status_code == 201:
             pricingplan = PricingPlan(response.json())
-            logging.info('Successfully created pricing plan with id {}'
+            logging.debug('Successfully created pricing plan with id {}'
                                                     .format(pricingplan.id))
             return pricingplan
         else:
@@ -276,7 +276,7 @@ class ProductService(object):
                         auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found pricing plan with id {}'.format(planId))
+            logging.debug('Found pricing plan with id {}'.format(planId))
             return PricingPlan(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -308,7 +308,7 @@ class ProductService(object):
 
         if response.status_code is 200:
             ls = PricingPlan(response.json())
-            logging.info('Successfully modified pricing plan with the id {}'
+            logging.debug('Successfully modified pricing plan with the id {}'
                         .format(ls.id))
             return ls
         else:
@@ -328,7 +328,7 @@ class ProductService(object):
                         auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully deleted pricing plan with id {}'
+            logging.debug('Successfully deleted pricing plan with id {}'
                                                     .format(planId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -371,7 +371,7 @@ class ProductService(object):
                                 auth=self._auth)
 
         if response.status_code == 200:
-            logging.info('Found {} product objects'.format(
+            logging.debug('Found {} product objects'.format(
                         len(response.json()['resources'])))
 
             ls = []
@@ -404,7 +404,7 @@ class ProductService(object):
 
         if response.status_code == 201:
             product = Product(response.json())
-            logging.info('Successfully created product with id {}'
+            logging.debug('Successfully created product with id {}'
                                                     .format(product.id))
             return product
         else:
@@ -426,7 +426,7 @@ class ProductService(object):
                         auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found product with id {}'.format(productId))
+            logging.debug('Found product with id {}'.format(productId))
             return Product(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -458,7 +458,7 @@ class ProductService(object):
 
         if response.status_code is 200:
             ls = Product(response.json())
-            logging.info('Successfully modified product with the id {}'
+            logging.debug('Successfully modified product with the id {}'
                         .format(ls.id))
             return ls
         else:
@@ -478,7 +478,7 @@ class ProductService(object):
                         auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully deleted product with id {}'
+            logging.debug('Successfully deleted product with id {}'
                                                     .format(productId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -526,7 +526,7 @@ class ProductService(object):
 
         if response.status_code is 200:
             catalogs = AllCatalogs(response.json())
-            logging.info('Found {} catalog details'.format(
+            logging.debug('Found {} catalog details'.format(
                                                         len(catalogs.catalogs)))
             return catalogs
         else:
@@ -585,7 +585,7 @@ class ProductService(object):
                                      auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found catalog {}'.format(catalogId))
+            logging.debug('Found catalog {}'.format(catalogId))
             return CatalogDetails(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -645,7 +645,7 @@ class ProductService(object):
                                      auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found product {} of catalog {}'.format(
+            logging.debug('Found product {} of catalog {}'.format(
                                                             catalogId, itemId))
             return ProductDetails(response.json())
         else:
