@@ -81,7 +81,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found {} users'.format(len(response.json()['resources'])))
+            logging.debug('Found {} users'.format(len(response.json()['resources'])))
             users = []
             for user in response.json()['resources']:
                 users.append(User(user))
@@ -148,11 +148,11 @@ class UserService(object):
 
             if response.status_code == 201:
                 usr = User(response.json())
-                logging.info('Successfully created user with id {}'.format(
+                logging.debug('Successfully created user with id {}'.format(
                                     usr.id))
                 fails = []
                 if email_verification:
-                    logging.info('Sending email verification to the user email(s)')
+                    logging.debug('Sending email verification to the user email(s)')
                     for email in usr.emails.emails:
                         try:
                             self.verify_email(usr.id, email.email['address'])
@@ -160,7 +160,7 @@ class UserService(object):
                             fails.append(e.args[0])
 
                 if mobile_verification:
-                    logging.info('Sending mobile verification to the user mobile(s)')
+                    logging.debug('Sending mobile verification to the user mobile(s)')
                     for mobile in usr.mobiles.mobiles:
                         try:
                             self.verify_sms_link(usr.id,
@@ -197,7 +197,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found user with id {}'.format(userId))
+            logging.debug('Found user with id {}'.format(userId))
             return User(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -232,7 +232,7 @@ class UserService(object):
 
         if response.status_code is 200:
             usr = User(response.json())
-            logging.info('Successfully modified user with the id {}'
+            logging.debug('Successfully modified user with the id {}'
                         .format(usr.id))
             return usr
         else:
@@ -251,7 +251,7 @@ class UserService(object):
                                              auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully deleted user with id {}'.format(userId))
+            logging.debug('Successfully deleted user with id {}'.format(userId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
                                      response.status_code)
@@ -270,7 +270,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found ligal info of the user {}'.format(userId))
+            logging.debug('Found ligal info of the user {}'.format(userId))
             return LegalInfo(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -305,7 +305,7 @@ class UserService(object):
                                            auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully sent the email verification request to the' +
+            logging.debug('Successfully sent the email verification request to the' +
                             ' user with id {}'.format(userId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -328,7 +328,7 @@ class UserService(object):
                                            auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully sent the mobile verification code to the' +
+            logging.debug('Successfully sent the mobile verification code to the' +
                 'mobile number {} and  user with id {}'.format(mobile, userId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -387,7 +387,7 @@ class UserService(object):
                                            auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully sent the mobile verification link to the' +
+            logging.debug('Successfully sent the mobile verification link to the' +
                 'mobile number {} and  user with id {}'.format(mobile, userId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -414,7 +414,7 @@ class UserService(object):
                                            auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully sent the invitation request')
+            logging.debug('Successfully sent the invitation request')
         else:
             raise TrivoreIDException(su.error_response_message(response),
                                      response.status_code)
@@ -434,7 +434,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found enterprise from user with id {}'.format(userId))
+            logging.debug('Found enterprise from user with id {}'.format(userId))
             return Enterprise(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -462,7 +462,7 @@ class UserService(object):
 
         if response.status_code is 200:
             ent = Enterprise(response.json())
-            logging.info('Successfully modified enterprise with the user id {}'
+            logging.debug('Successfully modified enterprise with the user id {}'
                                         .format(userId))
             return ent
         else:
@@ -484,7 +484,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found custom fields of the user with id {}'.format(userId))
+            logging.debug('Found custom fields of the user with id {}'.format(userId))
             return response.content
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -506,7 +506,7 @@ class UserService(object):
                                            auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully modified custom fields of the user id {}'
+            logging.debug('Successfully modified custom fields of the user id {}'
                                         .format(userId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -524,7 +524,7 @@ class UserService(object):
                                              auth = self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully deleted custom fields of the user with id {}'
+            logging.debug('Successfully deleted custom fields of the user with id {}'
                                                                 .format(userId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -545,7 +545,7 @@ class UserService(object):
 
 
         if response.status_code is 200:
-            logging.info('Found password requirements of the user with id {}'
+            logging.debug('Found password requirements of the user with id {}'
                                                             .format(userId))
             return PasswordRequirements(response.json())
         else:
@@ -566,7 +566,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully found strong identification of the user with id {}'
+            logging.debug('Successfully found strong identification of the user with id {}'
                                                             .format(userId))
             return StrongIdentification(response.json())
         else:
@@ -593,7 +593,7 @@ class UserService(object):
                                            auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully reported strong identification of the user with id {}'
+            logging.debug('Successfully reported strong identification of the user with id {}'
                                                             .format(userId))
             return StrongIdentification(response.json())
         else:
@@ -639,7 +639,7 @@ class UserService(object):
                                      auth=self._auth)
 
         if response.status_code == 200:
-            logging.info('Successfully got strong identification history.')
+            logging.debug('Successfully got strong identification history.')
 
             ls = []
             for l in response.json()['resources']:
@@ -665,7 +665,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully found strong identification of the user with id {}'
+            logging.debug('Successfully found strong identification of the user with id {}'
                                                             .format(userId))
             return StrongIdentification(response.json())
         else:
@@ -693,11 +693,11 @@ class UserService(object):
         if response.status_code is 200:
             result = PasswordUpdateResult(response.json())
             if result.success:
-                logging.info('Successfully changed the password of the user with id {}'
+                logging.debug('Successfully changed the password of the user with id {}'
                                                             .format(userId))
                 return result
             else:
-                logging.info('Failed to change the password of the user with id {}'
+                logging.debug('Failed to change the password of the user with id {}'
                                                             .format(userId))
                 return result
         else:
@@ -719,7 +719,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully found custom permissions of the user with id {}'
+            logging.debug('Successfully found custom permissions of the user with id {}'
                                                             .format(userId))
             return response.json()
         else:
@@ -746,7 +746,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully updated custom permissions of the user with id {}'
+            logging.debug('Successfully updated custom permissions of the user with id {}'
                                                             .format(userId))
             return response.json()
         else:
@@ -768,7 +768,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully found effective permissions of the user with id {}'
+            logging.debug('Successfully found effective permissions of the user with id {}'
                                                             .format(userId))
             return response.json()
         else:
@@ -790,7 +790,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully found builtin roles of the user with id {}'
+            logging.debug('Successfully found builtin roles of the user with id {}'
                                                             .format(userId))
             return response.json()
         else:
@@ -817,7 +817,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully updated builtin roles of the user with id {}'
+            logging.debug('Successfully updated builtin roles of the user with id {}'
                                                             .format(userId))
             return response.json()
         else:
@@ -839,7 +839,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully found custom roles of the user with id {}'
+            logging.debug('Successfully found custom roles of the user with id {}'
                                                             .format(userId))
             return response.json()
         else:
@@ -866,7 +866,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully updated custom roles of the user with id {}'
+            logging.debug('Successfully updated custom roles of the user with id {}'
                                                             .format(userId))
             return response.json()
         else:
@@ -900,7 +900,7 @@ class UserService(object):
                                            auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully migrated user with id {}'.format(userId))
+            logging.debug('Successfully migrated user with id {}'.format(userId))
             return User(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -920,7 +920,7 @@ class UserService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully got student state for user with id {}'
+            logging.debug('Successfully got student state for user with id {}'
                                                                 .format(userId))
             return StudentState(response.json())
         else:
@@ -946,7 +946,7 @@ class UserService(object):
                                            auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Successfully updated student state of the user {}'
+            logging.debug('Successfully updated student state of the user {}'
                                                                 .format(userId))
             return StudentState(response.json())
         else:
